numina.logger — Logging utilities — Numina 0.20.dev0 documentation

# `numina.logger` — Logging utilities

Extra logging handlers for the numina logging system.

class `numina.logger.` `FITSHistoryHandler`(header)

  Logging handler using HISTORY FITS cards

  `emit`(record)

    Do whatever it takes to actually log the specified logging record.

    This version is intended to be implemented by subclasses and so raises a NotImplementedError.

`numina.logger.` `log_to_history`(logger, name)

  Decorate function, adding a logger handler stored in FITS.